@@ -6,7 +6,9 @@
 import logging
 import os
 import re
-from collections import defaultdict, Counter
+import shutil
+import tempfile
+from collections import Counter, defaultdict, namedtuple
 from io import StringIO
 from pprint import pprint
 
@@ -18,12 +20,12 @@ import pint_pandas as pintpandas
 import pkg_resources
 import simplejson as json
 import yaml
-import tempfile
-import shutil
 
 ureg = pint.UnitRegistry()
 UNIQUENESS_SEP = " & "
 
+Validation = namedtuple("Validation", ["df", "isok", "report"])
+
 
 def yamlcat(*files):
     """concat YAML files and returns a StringIO object
@@ -208,6 +210,14 @@ class DataFrameSchematizer:
      ('life_nb', 1): ["'hg' is not of type 'integer'"],
      ('life_nb', 2): ['15 is greater than the maximum of 4']}
 
+    validate_dataframe returned a namedtuple:
+
+    >>> val = v.validate_dataframe(df)
+    >>> val._fields
+    ('df', 'isok', 'report')
+    >>> val.isok
+    False
+
     The schema used for validation can be accessed by:
 
     >>> schema = v.build()
@@ -308,6 +318,7 @@ class DataFrameSchematizer:
         self._target_units = None
         self.uniqueness_sets = defaultdict(list)
         self.xcalling = {}
+        self.mandatory_if_checks = {}
 
     def build(self):
         """build and return schema"""
@@ -336,6 +347,10 @@ class DataFrameSchematizer:
                 "colname": ext_colname,
                 "func": func,
             }
+        for colname, query in self.mandatory_if_checks.items():
+            if "mandatory_if" not in schema:
+                schema["mandatory_if"] = {}
+            schema["mandatory_if"][colname] = query
         return schema
 
     def _add_columns_from_json(self, jsontxt):
@@ -371,6 +386,7 @@ class DataFrameSchematizer:
         uniqueness_id=None,
         must_exist_in=None,
         must_not_exist_in=None,
+        mandatory_if=None,
         units=None,
         **kwargs,
     ):
@@ -388,6 +404,8 @@ class DataFrameSchematizer:
             self.xcalling[name] = tuple(must_exist_in.split("::") + ["isin"])
         if must_not_exist_in:
             self.xcalling[name] = tuple(must_not_exist_in.split("::") + ["~isin"])
+        if mandatory_if:
+            self.mandatory_if_checks[name] = mandatory_if
         # ---------------------------------------------------------
         if len(types) > 1:
             items = {"anyOf": [{"type": typ} for typ in types]}
@@ -523,7 +541,8 @@ class DataFrameSchematizer:
         if dummies:
             df.drop(columns=dummies, inplace=True)
         report = {**early_report, **report}
-        return df, len(report) == 0, dict(report)
+        val = Validation(df, len(report) == 0, dict(report))
+        return val
 
 
 def _is_typing_error(error):
@@ -708,10 +727,10 @@ class ValidatorMixin:
     def _validate_tab(self, tabname):
         """validate a tab using the provided scheme"""
         if tabname not in self._schemas:
-            return (None, True, {}), {}
+            return Validation(None, True, {})
         schema = self._schemas[tabname]
         result = schema.validate_dataframe(self._data[tabname])
-        return result, schema.xcalling
+        return result
 
     def validate(self, row_reporting_offset="data"):
         """
@@ -724,11 +743,14 @@ class ValidatorMixin:
             self._raw_data = {tabname: df.copy() for tabname, df in self._data.items()}
         ret = defaultdict(dict)
         xcallings = {}
+        mandatory_if_checks = {}
         for tabname, df in self._data.copy().items():
-            (df, is_ok, report), xcalling = self._validate_tab(tabname)
+            df, is_ok, report = self._validate_tab(tabname)
             if tabname in self._schemas:
                 if xcalling := self._schemas[tabname].xcalling:
                     xcallings[tabname] = xcalling
+                if mandatory_if_check := self._schemas[tabname].mandatory_if_checks:
+                    mandatory_if_checks[tabname] = mandatory_if_check
             if df is None:
                 # tabname not described in schema; drop it
                 logging.warning(
@@ -740,6 +762,19 @@ class ValidatorMixin:
             if not is_ok:
                 ret[tabname] = report
         # ---------------------------------------------------------------------
+        # mandatory_if_checks
+        for tabname, specs in mandatory_if_checks.items():
+            for colname, check_expr in specs.items():
+                required_missing_values = df.query(check_expr)[colname]
+                required_missing_values = required_missing_values[
+                    required_missing_values.isnull()
+                ]
+                for row_nb in required_missing_values.index:
+                    ret[tabname][
+                        (colname, row_nb)
+                    ] = f"This value is mandatory for `{check_expr}`"
+
+        # ---------------------------------------------------------------------
         # check cross-references calls
         for src_tabname, targets in xcallings.items():
             for src_colname, (target_tabname, target_colname, func) in targets.items():
