@@ -290,10 +290,9 @@ def test_VData_00():
         ("life_nb", 1): ["'hg' is not of type 'integer'"],
         ("life_nb", 2): ["15 is greater than the maximum of 4"],
     }
-    (df, is_valid, errors), xcalling = data._validate_tab("test")
+    df, is_valid, errors = data._validate_tab("test")
     assert is_valid is False
     assert errors == expected_report
-    assert xcalling == {}
 
 
 # =============================================================================
@@ -323,10 +322,9 @@ def test_IVData_00(datadir):
     data.read_schema(os.path.join(indir, "test_00.schema.yaml"))
     for tab in ("names", "cars", "empty"):
         print('checking "%s"' % tab, end="... ")
-        (df, is_ok, errors), xcalling = data._validate_tab(tab)
+        df, is_ok, errors = data._validate_tab(tab)
         assert is_ok is True
         assert errors == {}
-        assert xcalling == {}
     # ------------------------------------------------------------------------
     # export and reimport to/from various formats
     for extension in (".cfg", ".xlsx", ".ini"):
@@ -342,7 +340,7 @@ def test_IVData_00(datadir):
         data_new.read_schema(os.path.join(indir, "test_00.schema.yaml"))
         for tab in data._data.keys():
             print('checking "%s"' % tab, end="... ")
-            (df, is_ok, errors), xcalling = data_new._validate_tab(tab)
+            df, is_ok, errors = data_new._validate_tab(tab)
             try:
                 assert is_ok is True
             except:
@@ -835,3 +833,30 @@ def test_IVData_09_must_exist_in(datadir):
     }
 
     assert ret == expected_errors
+
+
+def test_IVData_10_mandatory_if(datadir):
+    """check 'mandatory_if' req"""
+    indir, outdir = datadir
+    data = IVData()
+    data.read_excel(os.path.join(indir, "test_10_mandatory_if.xlsx"))
+    data.read_schema(os.path.join(indir, "test_10_mandatory_if.yaml"))
+    ret = data.validate("spreadsheet")
+    expected_errors = {
+        "beams": {
+            ("beam_id", 5): ["'value `6.0` not found in `beam_def::id`"],
+            ("color_id", 7): [
+                "'a' is not of type 'integer'",
+                "'value `a` not found in `colors::id`",
+            ],
+        },
+        "colors": {
+            ("blue_subtype", 6): "This value is mandatory for `id>3`",
+            ("blue_subtype", 7): "This value is mandatory for `id>3`",
+            ("blue_subtype", 8): "This value is mandatory for `id>3`",
+            ("id", 2): ["'value `1` unexpectidely found in `beam_def::id`"],
+            ("id", 5): ["'value `4` unexpectidely found in `beam_def::id`"],
+            ("red_subtype", 4): "This value is mandatory for `name=='red'`",
+        },
+    }
+    assert ret == expected_errors
